@@ -1,42 +1,37 @@
-package POE::Filter::HTTPChunk;
-BEGIN {
-  $POE::Filter::HTTPChunk::VERSION = '0.900_161';
-}
-# vim: ts=2 sw=2 expandtab
+# $Id: HTTPChunk.pm 224 2005-09-17 18:22:10Z rcaputo $
 
-use warnings;
+package POE::Filter::HTTPChunk;
 use strict;
 
 use Carp;
 use bytes;
-use base 'POE::Filter';
 
 use HTTP::Response;
 
-use constant FRAMING_BUFFER  => 0;
-use constant CURRENT_STATE   => 1;
-use constant CHUNK_SIZE      => 2;
-use constant CHUNK_BUFFER    => 3;
-use constant TRAILER_HEADERS => 4;
+sub FRAMING_BUFFER   () { 0 }
+sub CURRENT_STATE    () { 1 }
+sub CHUNK_SIZE       () { 2 }
+sub CHUNK_BUFFER     () { 3 }
+sub TRAILER_HEADERS  () { 4 }
 
-use constant STATE_SIZE      => 0x01;  # waiting for a status line
-use constant STATE_DATA      => 0x02;  # received status, looking for header or end
-use constant STATE_TRAILER   => 0x04;  # received status, looking for header or end
+sub STATE_SIZE    () { 0x01 }  # waiting for a status line
+sub STATE_DATA    () { 0x02 }  # received status, looking for header or end
+sub STATE_TRAILER () { 0x04 }  # received status, looking for header or end
 
-use constant DEBUG           => 0;
+sub DEBUG () { 0 }
 
 sub new {
-  my ($class) = @_;
+  my $type = shift;
 
   my $self = bless [
-    [],         # FRAMING_BUFFER
+    [],          # FRAMING_BUFFER
     STATE_SIZE, # CURRENT_STATE
     0,          # CHUNK_SIZE
-    '',         # CHUNK_BUFFER
+    '',          # CHUNK_BUFFER
     undef,      # TRAILER_HEADERS
-  ], $class;
+  ], $type;
 
-  return $self;
+  $self;
 }
 
 my $HEX = qr/[\dA-Fa-f]/o;
@@ -130,8 +125,7 @@ sub get_one {
       my $len = $self->[CHUNK_SIZE] - length ($self->[CHUNK_BUFFER]);
       DEBUG and
         warn "going for length ", $self->[CHUNK_SIZE], " (need $len more)";
-      my $newchunk = $self->[CHUNK_BUFFER];
-      $self->[CHUNK_BUFFER] = "";
+      my $newchunk = delete $self->[CHUNK_BUFFER];
       $newchunk .= substr ($chunk, 0, $len, '');
       #warn "got " . length($newchunk) . " bytes of data";
       if (length $newchunk != $self->[CHUNK_SIZE]) {
@@ -170,12 +164,7 @@ sub get_one {
         unshift (@{$self->[FRAMING_BUFFER]}, $chunk) if (length $chunk);
         return $retval;
       }
-      if (@{$self->[FRAMING_BUFFER]}) {
-          $self->[FRAMING_BUFFER]->[0] = $chunk . $self->[FRAMING_BUFFER]->[0];
-      } else {
-          unshift (@{$self->[FRAMING_BUFFER]}, $chunk);
-          return $retval;
-      }
+      unshift (@{$self->[FRAMING_BUFFER]}, $chunk);
     }
   }
   return $retval;
@@ -194,114 +183,3 @@ sub get_pending {
   return $self->[FRAMING_BUFFER] if @{$self->[FRAMING_BUFFER]};
   return undef;
 }
-
-__END__
-
-# {{{ POD
-
-=head1 NAME
-
-POE::Filter::HTTPChunk - Non-blocking incremental HTTP chunk parser.
-
-=head1 VERSION
-
-version 0.900_161
-
-=head1 SYNOPSIS
-
-  # Not a complete program.
-  use POE::Filter::HTTPChunk;
-  use POE::Wheel::ReadWrite;
-  sub setup_io {
-    $_[HEAP]->{io_wheel} = POE::Wheel::ReadWrite->new(
-      Filter => POE::Filter::HTTPChunk->new(),
-      # See POE::Wheel::ReadWrite for other required parameters.
-    );
-  }
-
-=head1 DESCRIPTION
-
-This filter parses HTTP chunks from a data stream.  It's used by
-POE::Component::Client::HTTP to do the bulk of the low-level HTTP
-parsing.
-
-=head1 CONSTRUCTOR
-
-=head2 new
-
-C<new> takes no parameters and returns a shiny new
-POE::Filter::HTTPChunk object ready to use.
-
-=head1 METHODS
-
-POE::Filter::HTTPChunk supports the following methods.  Most of them
-adhere to the standard POE::Filter API.  The documentation for
-POE::Filter explains the API in more detail.
-
-=head2 get_one_start ARRAYREF
-
-Accept an arrayref containing zero or more raw data chunks.  They are
-added to the filter's input buffer.  The filter will attempt to parse
-that data when get_one() is called.
-
-  $filter_httpchunk->get_one_start(\@stream_data);
-
-=head2 get_one
-
-Parse a single HTTP chunk from the filter's input buffer.  Data is
-entered into the buffer by the get_one_start() method.  Returns an
-arrayref containing zero or one parsed HTTP chunk.
-
-  $ret_arrayref = $filter_httpchunk->get_one();
-
-=head2 get_pending
-
-Returns an arrayref of stream data currently pending parsing.  It's
-used to seamlessly transfer unparsed data between an old and a new
-filter when a wheel's filter is changed.
-
-  $pending_arrayref = $filter_httpchunk->get_pending();
-
-=head1 SEE ALSO
-
-L<POE::Filter>, L<POE>.
-
-=head1 BUGS
-
-None are known at this time.
-
-=head1 AUTHOR & COPYRIGHTS
-
-POE::Filter::HTTPChunk is...
-
-=over 2
-
-=item
-
-Copyright 2005-2006 Martijn van Beers
-
-=item
-
-Copyright 2006 Rocco Caputo
-
-=back
-
-All rights are reserved.  POE::Filter::HTTPChunk is free software; you
-may redistribute it and/or modify it under the same terms as Perl
-itself.
-
-=head1 CONTACT
-
-Rocco may be contacted by e-mail via L<mailto:rcaputo@cpan.org>, and
-Martijn may be contacted by email via L<mailto:martijn@cpan.org>.
-
-The preferred way to report bugs or requests is through RT though.
-See
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=POE-Component-Client-HTTP>
-or mail L<mailto:bug-POE-Component-Client-HTTP@rt.cpan.org>
-
-For questions, try the L<POE> mailing list (poe@perl.org)
-
-=cut
-
-# }}} POD
\ No newline at end of file
